**********
Chapter 04
**********

Schema composition
==================

Binding Test
************

**Schema**

.. literalinclude:: /../tests/fixtures/defxmlschema/chapter04.xsd
   :language: xml
   :lines: 2-

.. literalinclude:: /../tests/fixtures/defxmlschema/chapter04.py
   :language: python

**XML Document**

.. literalinclude:: /../tests/fixtures/defxmlschema/chapter04.xml
   :language: xml
   :lines: 2-

**xsData XML Document**

.. literalinclude:: /../tests/fixtures/defxmlschema/chapter04.xsdata.xml
   :language: xml
   :lines: 2-

**xsData JSON**

.. literalinclude:: /../tests/fixtures/defxmlschema/chapter04.json
   :language: json

.. admonition:: Samples Source
    :class: hint

    `Definitive XML Schema <http://www.datypic.com/books/defxmlschema/>`_
    by Priscilla Walmsley (c) 2012 Prentice Hall PTR
